import * as React from 'react';
export declare type Promisable = () => Promise<any> | any;
export declare type RouteInject = {
    [key: string]: any;
};
export interface RouteProps {
    name: string;
    path: string;
    component: any;
    template?: any;
    beforeRender?: Array<(route: InjectedRoute) => Promise<any | void>>;
    inject?: RouteInject;
}
export declare type RouteParams = {
    [key: string]: any;
};
export interface InjectedRoute {
    urn: string;
    params: RouteParams;
    inject: RouteInject;
}
export declare class RctRoute {
    name: string;
    path: string;
    Component: any;
    templates: Array<any>;
    beforeRender: Array<(route: InjectedRoute) => Promise<any | void>>;
    params: RouteParams;
    inject: RouteInject;
    urn: string;
    constructor(props: RouteProps);
    replaceInject(inject: RouteInject): void;
    addTemplate(template: any): this;
    addParams(params: RouteParams, url: string): this;
    inheritParentData(parent: Collection | RootCollection): this;
    formatForInject(): InjectedRoute;
}
export interface RootCollectionProps {
    error?: any;
    notFound?: any;
    path?: string;
    template?: any;
}
export declare class RootCollection {
    collections: Array<Collection>;
    error: any;
    name: string;
    notFound: any;
    path: string;
    routes: Array<RctRoute>;
    templates: Array<any>;
    urn: string;
    constructor(props: RootCollectionProps);
    addRoute(route: RctRoute): this;
    addCollection(collection: Collection): this;
    build(): this;
}
export interface CollectionProps {
    name: string;
    path: string;
    template?: any;
}
export declare class Collection {
    name: string;
    urn: string;
    path: string;
    templates: Array<any>;
    routes: Array<RctRoute>;
    collections: Array<Collection>;
    constructor(props: CollectionProps);
    addRoute(route: RctRoute): this;
    addCollection(collection: Collection): this;
    addTemplate(template: any): this;
    inheritParentData(parent: Collection | RootCollection): this;
}
export interface RouterProps {
    routes: RootCollection;
}
export interface RouterState {
    route: RctRoute;
}
export interface TemplateProps {
    route: InjectedRoute;
}
export interface TemplateBuilderProps {
    route: InjectedRoute;
    templates: Array<React.ComponentClass<TemplateProps>>;
    children: React.ReactElement<any>;
}
export interface RouteRendererProps {
    route: RctRoute;
    errorView: any;
}
export interface RouteRendererState {
    route: RctRoute | null;
}
export declare class Router extends React.Component<RouterProps, RouterState> {
    routes: RootCollection;
    constructor(props: RouterProps);
    routeTo(url: string, collection: Collection | RootCollection): RctRoute;
    render(): JSX.Element;
}
export interface Go<E extends string> {
    (ptr: E, params: {
        [key: string]: any;
    }, e?: any): void;
}
export declare function createGo<E extends string>(routes: RootCollection): Go<E>;
